/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2006-2008 - INRIA - Allan CORNET <allan.cornet@inria.fr>
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

#include <string.h>
#include "gw_special_functions.h"
#include "machine.h"
/*--------------------------------------------------------------------------*/
extern int C2F(intscalerf)(char *id,unsigned long fname_len);
/*--------------------------------------------------------------------------*/
int sci_calerf(char *fname,unsigned long fname_len)
{
	C2F(intscalerf)(fname,fname_len);
	return 0;
}
/*--------------------------------------------------------------------------*/
